---
title: <span class="badge object-type-enum"></span> QueryEditorMode
---
# <span class="badge object-type-enum"></span> QueryEditorMode

## Definition

```python
class QueryEditorMode(enum.StrEnum):
    CODE = "code"
    BUILDER = "builder"
```
